diff --git a/BuildUbuntu.md b/BuildUbuntu.md
index df794dc..6a50337 100644
--- a/BuildUbuntu.md
+++ b/BuildUbuntu.md
@@ -4,20 +4,21 @@
 
 *(contributed by Danny Heijl)*
 
-May 21 2023: Updated for ART 1.20 and exiv2 0.28.x branch:
+May 21 2023: Updated for ART 1.20 and exiv2 main branch:
 
-- new exiv2 dependency libinih-dev
+- new exiv2 dependencies: libinih-dev libbrotli-dev
 
 ## Prerequisites
 
 These instructions were tested on Ubuntu 20.04 and 22.04 (Linux Mint 20 and 21), so should work on any Debian based distro.
-They assume you want to use the latest and greatest versions of all dependencies. You could of course choose to use the "stable" released versions instead.
+They assume you want to use (cloned from GitHub) the latest and greatest versions of all dependencies. 
+You could of course choose to download and use the latest "stable" released source versions instead.
 
 - install the necessary development packages:
 
 ```bash
 sudo apt install autoconf libtool
-sudo apt install git build-essential cmake curl pkg-config libgtk-3-dev libgtkmm-3.0-dev librsvg2-dev liblcms2-dev libfftw3-dev libiptcdata0-dev libtiff5-dev libcanberra-gtk3-dev libinih-dev
+sudo apt install git build-essential cmake curl pkg-config libgtk-3-dev libgtkmm-3.0-dev librsvg2-dev liblcms2-dev libfftw3-dev libiptcdata0-dev libtiff5-dev libcanberra-gtk3-dev libinih-dev libbrotli-dev
 ```
 
 - If you want to use the latest gcc, you can install gcc-12 and g++12 first before building anything, as per <https://www.linuxcapable.com/install-gcc-compiler-build-essential-on-ubuntu-2>:
@@ -55,17 +56,19 @@ sudo make install
 sudo ldconfig
 ```
 
-- As of ART 1.20 you can use the new **exiv2 0.28.x** branch, instead of exiv2 0.27.maintenance branch (ART does not compile with the **exiv2** “main” branch due to API changes, and to get Canon CR3 support from exiv2 you have to use a **recent exiv2** version. Without a recent exiv2 library linked in you would have to install **exiftool** for Canon CR3 support: `sudo apt install exiftool`.)
+- As of ART 1.20 you can use the exiv2 main (1.00.xx) branch or the latest release (0.28.x) branch, instead of exiv2 0.27.maintenance branch. To get Canon CR3 support from exiv2 you have to use a **recent exiv2** version (without a recent exiv2 library linked in you would have to install **exiftool** for Canon CR3 support: `sudo apt install exiftool`).
 
-  - clone and install exiv2 0.28.x from github, and cd to to the cloned exiv2 folder:
+  - if you have an outdated exiv2 package installed, remove it now: `sudo apt remove exiv2 libexiv2-dev`
+  - since 0.28.x the tests are no longer built by default, so you have to skip the `ctest` step
+  - clone and install exiv2 (main branch or 0.28.x) from github, and cd to to the cloned exiv2 folder:
 
 ```bash
-mkdir build && cd build
-cmake -DCMAKE_BUILD_TYPE=Release -DEXIV2_ENABLE_BMFF=On ..
-cmake --build .
-ctest –verbose
-sudo apt remove exiv2 libexiv2-dev
-sudo make install
+sudo rm -rf build
+mkdir -p build
+cmake -S . -B build -DCMAKE_BUILD_TYPE=Release -DEXIV2_ENABLE_BMFF=On 
+cmake --build build
+sudo cmake --install build
+sudo ldconfig
 ```
 
 - ART needs MIMALLOC, so clone it from Github (<https://github.com/microsoft/mimalloc>) and build it:
@@ -93,7 +96,8 @@ sudo make install
 
 - download the build-art script (raw) from <https://bitbucket.org/agriggio/art/src/master/tools/build-art>
 
-- Make build-art executable and execute it:
+- you may have to remove an older build first: `rm -r programs/art ptograms/code-art`
+- Make build-art executable `(chmod +x)` and execute it:
 
 ```bash
 chmod +x ./build-art
